==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/usermanager/lang/no/lang.php <==
<?php
/**
 * Norwegianlanguage file
 *
 * @author Thomas Nygreen <nygreen@gmail.com>
 * @author Arild Burud <arildb@met.no>
 * @author Torkill Bruland <torkar-b@online.no>
 * @author Rune M. Andersen <rune.andersen@gmail.com>
 */
$lang['menu']                  = 'Behandle brukere';
$lang['noauth']                = '(autentisering av brukere ikke tilgjengelig)';
$lang['nosupport']             = '(behandling av brukere støttes ikke)';
$lang['badauth']               = 'ugyldig autentiseringsmekanisme';
$lang['user_id']               = 'Bruker';
$lang['user_pass']             = 'Passord';
$lang['user_name']             = 'Fullt navn';
$lang['user_mail']             = 'E-post';
$lang['user_groups']           = 'Grupper';
$lang['field']                 = 'Felt';
$lang['value']                 = 'Verdi';
$lang['add']                   = 'Legg til';
$lang['delete']                = 'Slett';
$lang['delete_selected']       = 'Slett utvalgte';
$lang['edit']                  = 'Rediger';
$lang['edit_prompt']           = 'Rediger denne brukeren';
$lang['modify']                = 'Lagre endringer';
$lang['search']                = 'Søk';
$lang['search_prompt']         = 'Start søk';
$lang['clear']                 = 'Tilbakestill søkefilter';
$lang['filter']                = 'Filter';
$lang['summary']               = 'Viser brukere %1$d-%2$d av %3$d. %4$d users total.';
$lang['nonefound']             = 'Ingen brukere funnet. %d brukere totalt.';
$lang['delete_ok']             = '%d brukere slettet.';
$lang['delete_fail']           = '%d kunne ikke slettes.';
$lang['update_ok']             = 'Brukeren ble oppdatert';
$lang['update_fail']           = 'Oppdatering av brukeren feilet';
$lang['update_exists']         = 'Endring av brukernavn feilet. Det oppgitte brukernavnet (%s) eksisterer allerede (alle andre endringer vil bli gjort).';
$lang['start']                 = 'første';
$lang['prev']                  = 'forrige';
$lang['next']                  = 'neste';
$lang['last']                  = 'siste';
$lang['edit_usermissing']      = 'Fant ikke valgte brukere. Det oppgitte brukernavnet kan ha blitt slettet eller endret et annet sted.';
$lang['user_notify']           = 'Varsle bruker';
$lang['note_notify']           = 'E-post med varsling blir bare sendt hvis brukeren blir gitt nytt passord.';
$lang['note_group']            = 'Nye brukere vil bli lagt til standardgruppen (%s) hvis ingen gruppe oppgis.';
$lang['add_ok']                = 'Brukeren ble lagt til';
$lang['add_fail']              = 'Brukeren kunne ikke legges til';
$lang['notify_ok']             = 'Varsling sendt';
$lang['notify_fail']           = 'Varsling kunne ikke sendes';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/usermanager/lang/no/lang.php <==
<?php
/**
 * Norwegianlanguage file
 *
 * @author Thomas Nygreen <nygreen@gmail.com>
 * @author Arild Burud <arildb@met.no>
 * @author Torkill Bruland <torkar-b@online.no>
 * @author Rune M. Andersen <rune.andersen@gmail.com>
 * @author Jakob Vad Nielsen (me@jakobnielsen.net)
 * @author Kjell Tore Næsgaard  <kjell.t.nasgaard@ntnu.no>
 */
$lang['menu']                  = 'Behandle brukere';
$lang['noauth']                = '(autentisering av brukere ikke tilgjengelig)';
$lang['nosupport']             = '(behandling av brukere støttes ikke)';
$lang['badauth']               = 'ugyldig autentiseringsmekanisme';
$lang['user_id']               = 'Bruker';
$lang['user_pass']             = 'Passord';
$lang['user_name']             = 'Fullt navn';
$lang['user_mail']             = 'E-post';
$lang['user_groups']           = 'Grupper';
$lang['field']                 = 'Felt';
$lang['value']                 = 'Verdi';
$lang['add']                   = 'Legg til';
$lang['delete']                = 'Slett';
$lang['delete_selected']       = 'Slett utvalgte';
$lang['edit']                  = 'Rediger';
$lang['edit_prompt']           = 'Rediger denne brukeren';
$lang['modify']                = 'Lagre endringer';
$lang['search']                = 'Søk';
$lang['search_prompt']         = 'Start søk';
$lang['clear']                 = 'Tilbakestill søkefilter';
$lang['filter']                = 'Filter';
$lang['summary']               = 'Viser brukere %1$d-%2$d av %3$d. %4$d users total.';
$lang['nonefound']             = 'Ingen brukere funnet. %d brukere totalt.';
$lang['delete_ok']             = '%d brukere slettet.';
$lang['delete_fail']           = '%d kunne ikke slettes.';
$lang['update_ok']             = 'Brukeren ble oppdatert';
$lang['update_fail']           = 'Oppdatering av brukeren feilet';
$lang['update_exists']         = 'Endring av brukernavn feilet. Det oppgitte brukernavnet (%s) eksisterer allerede (alle andre endringer vil bli gjort).';
$lang['start']                 = 'første';
$lang['prev']                  = 'forrige';
$lang['next']                  = 'neste';
$lang['last']                  = 'siste';
$lang['edit_usermissing']      = 'Fant ikke valgte brukere. Det oppgitte brukernavnet kan ha blitt slettet eller endret et annet sted.';
$lang['user_notify']           = 'Varsle bruker';
$lang['note_notify']           = 'E-post med varsling blir bare sendt hvis brukeren blir gitt nytt passord.';
$lang['note_group']            = 'Nye brukere vil bli lagt til standardgruppen (%s) hvis ingen gruppe oppgis.';
$lang['note_pass']             = 'Passordet vil bli autogenerert dersom feltet er tomt og varsle bruker er valgt.';
$lang['add_ok']                = 'Brukeren ble lagt til';
$lang['add_fail']              = 'Brukeren kunne ikke legges til';
$lang['notify_ok']             = 'Varsling sendt';
$lang['notify_fail']           = 'Varsling kunne ikke sendes';
